@@ -49,8 +49,7 @@ Config::initDefaultValues (void)
     m_keyboard_layout = CHEWING_DEFAULT;
 
     m_init_chinese = TRUE;
-    m_init_full_english = FALSE;
-    m_init_full_punct = TRUE;
+    m_init_full_width = FALSE;
     m_init_trad_chinese = TRUE;
 
     m_always_input_numbers = FALSE;
