@@ -149,14 +149,14 @@ PhoneticEditor::processSpace (guint keyval, guint keycode,
             return FALSE;
 
         if (m_text.empty ()) {
-            assert (is_half_english (' '));
-            if (m_props.modeFullEnglish ()) {
-                String english;
-                half_english_to_full_english (keyval, english);
-                commit (english);
+            assert (is_special_symbol (' '));
+            if (m_props.modeFullWidth ()) {
+                String symbol;
+                convert_special_symbol (keyval, symbol);
+                commit (symbol);
             } else {
-                String english = ' ';
-                commit (english);
+                String symbol = ' ';
+                commit (symbol);
             }
             return TRUE;
         }
@@ -956,13 +956,28 @@ PhoneticEditor::getZhuyinCursor (void)
 }
 
 gboolean
-PhoneticEditor::insertPunct (guint ch)
+PhoneticEditor::insertSymbol (guint keyval)
 {
-    /* for punctuations. */
-    if (is_half_punct (ch)) {
-        if (m_props.modeFullPunct ()) {
+    /* for symbols. */
+    if (is_full_width_symbol (keyval)) {
+
+        if (is_special_symbol (keyval)) {
             String choice;
-            assert (half_punct_to_full_punct (ch, choice));
+            assert (convert_special_symbol (keyval, choice));
+
+            String lookup;
+            int ch = find_lookup_key (choice);
+            if (ch != 0)
+                lookup = (gchar) ch;
+
+            insert_symbol (m_text, m_cursor++, BUILTIN_SYMBOL_TYPE,
+                           lookup, choice);
+            return TRUE;
+        }
+
+        if (m_props.modeFullWidth ()) {
+            String choice;
+            assert (convert_full_width_symbol (keyval, choice));
 
             String lookup;
             int ch = find_lookup_key (choice);
@@ -972,7 +987,7 @@ PhoneticEditor::insertPunct (guint ch)
             insert_symbol (m_text, m_cursor++, BUILTIN_SYMBOL_TYPE,
                            lookup, choice);
         } else {
-            String choice = (gchar)ch;
+            String choice = (gchar) keyval;
             insert_symbol (m_text, m_cursor++, BUILTIN_SYMBOL_TYPE,
                            "", choice);
         }
@@ -984,35 +999,7 @@ PhoneticEditor::insertPunct (guint ch)
 }
 
 gboolean
-PhoneticEditor::insertEnglish (guint ch)
-{
-    /* for English. */
-    if (is_half_english (ch)) {
-        if (m_props.modeFullEnglish ()) {
-            String choice;
-            assert (half_english_to_full_english (ch, choice));
-
-            String lookup;
-            int ch = find_lookup_key (choice);
-            if (ch != 0)
-                lookup = (gchar) ch;
-
-            insert_symbol (m_text, m_cursor++, BUILTIN_SYMBOL_TYPE,
-                           lookup, choice);
-        } else {
-            String choice = (gchar) ch;
-            insert_symbol (m_text, m_cursor++, BUILTIN_SYMBOL_TYPE,
-                           "", choice);
-        }
-
-        return TRUE;
-    }
-
-    return FALSE;
-}
-
-gboolean
-PhoneticEditor::insertNumbers (guint ch)
+PhoneticEditor::insertNumbers (guint keyval)
 {
     /* for input pad numbers. */
     static const guint keyvals[] = {IBUS_KP_Delete, IBUS_KP_Insert,
@@ -1035,7 +1022,7 @@ PhoneticEditor::insertNumbers (guint ch)
         return FALSE;
 
     for (size_t i = 0; i < G_N_ELEMENTS (keyvals); ++i) {
-        if (keyvals[i] == ch) {
+        if (keyvals[i] == keyval) {
             String choice;
             choice += numbers[i];
 
