@@ -259,13 +259,7 @@ ZhuyinEditor::insert (guint keyval, guint keycode, guint modifiers)
         return TRUE;
     }
 
-    if (insertPunct (keyval)) {
-        updateZhuyin ();
-        update ();
-        return TRUE;
-    }
-
-    if (insertEnglish (keyval)) {
+    if (insertSymbol (keyval)) {
         updateZhuyin ();
         update ();
         return TRUE;
