@@ -134,6 +134,12 @@ ZhuyinEngine::processKeyEvent (guint keyval, guint keycode, guint modifiers)
         }
     }
 
+    if (modifiers == IBUS_SHIFT_MASK && keyval == IBUS_space) {
+        m_props.toggleModeFullWidth ();
+        m_prev_pressed_key = keyval;
+        return TRUE;
+    }
+
     if (m_props.modeChinese ()) {
         retval = m_editors[m_input_mode]->processKeyEvent
             (keyval, keycode, modifiers);
